<?php

use Illuminate\Support\Carbon;
use App\Maquinas;


function formatearDosCifras($numero) {
    // Convertir el número a una cadena y agregar un cero adelante si solo tiene una cifra
    return str_pad($numero, 2, '0', STR_PAD_LEFT);
}


function formatearTiempo($numero) {
    // Inicializar el arreglo de resultado
    $arreglo = array(
        'horas' => 0,
        'minutos' => $numero
    );

    // Verificar si el número es mayor o igual a 60
    if ($numero >= 60) {
        // Calcular las horas y minutos
        $arreglo['horas'] = floor($numero / 60);
        $arreglo['minutos'] = $numero % 60;
    }

    $arreglo['horas'] = intval($arreglo['horas']);
    $arreglo['minutos'] = intval($arreglo['minutos']);

    return $arreglo;
}




?>

@extends('layouts.app')
@section('content')
    @extends('fabricacion.menu')


    <div id="contenedor-dashboard" class="container-fluid">
        <div class="row ">
            <div class="col-md-12">
                <h2>Reporte diario de Producción</h2>
            </div>
        </div>
    </div>
    <div id="contenedor-dashboard" class="container-fluid">
        <div class="row ">
            <div class="col-md-3">
                <form method="POST" action="{{ route('fabricacion.historico_reporte') }}">
                    @csrf
                    <div class="input-group mb-3">
                        <input type="date" name="date" class="form-control rounded-0"
                            value="{{ \Carbon\Carbon::now()->format('Y-m-d') }}">
                        <button class="btn btn-outline-primary rounded-0" type="submit" id="button-addon2">Buscar</button>
                    </div>
                </form>
            </div>
        </div>
        <div class="col">
            <h5>Reporte de:  {{ $fechaAyer }}</b></h5>
        </div>
    </div>
    </div>
    <div class="container-fluid">

        <table class="table table-bordered">
            <thead class="thead-light">
                <tr>
                    <th>Maquina</th>
                    <th style="width: 30px;">Horas trabajadas</th>
                    <th>Descripción</th>
                    <th style="width: 20px;">Cantidad producida</th>
                    <th style="width: 20px;">Medida</th>
                    <th style="width: 40px;">Rendimiento por hora</th>
                    <th>Observación</th>
                </tr>
            </thead>
            <tbody>

                @foreach ($reportes as $reporte)
                    <tr>
                        <td>
                            <?php
                            $maquina = Maquinas::find($reporte->id_maquina);
                            echo $maquina->maquina;
                            ?>
                        </td>
                        <td><?php
                            $resultado = formatearTiempo($reporte->total_minutos);
                            if ($resultado['horas'] >= 1) {
                                echo formatearDosCifras($reporte->total_horas+$resultado['horas']);
                                echo ":";
                                echo formatearDosCifras($resultado['minutos']);
                            }else{
                                echo formatearDosCifras($reporte->total_horas);
                                echo ":";
                                echo formatearDosCifras($resultado['minutos']);
                            }

                        ?></td>
                        <td>{{ $reporte->trabajo }}</td>
                        <td>{{ number_format($reporte->total_cantidad, 2, '.', ',') }}</td>
                        <td>{{ $reporte->medida }}</td>
                        <td>
                            <?php
                            if ($reporte->total_cantidad) {
                                $promedio = $reporte->total_cantidad / abs($reporte->total_horas);
                                echo number_format($promedio, 2, '.', ',');
                            }
                            
                            ?>
                        </td>
                        <td>{{ $reporte->observacion }}</td>
                    </tr>
                @endforeach
            </tbody>
            <tfoot>
                <tr>
                    <td>Observaciones: <?php if (count($reportesGeneral)==0){ echo 'No hay comentarios generales'; } else { echo $reportesGeneral[0]->observacion; } ?></td>
                </tr>
            </tfoot>
        </table>

    </div>
@endsection
